lv_area_diff

Function lv_area_diff 

pub unsafe extern "C" fn lv_area_diff(
    res_p: *mut lv_area_t,
    a1_p: *const lv_area_t,
    a2_p: *const lv_area_t,
) -> i8
Get resulting sub areas after removing the common parts of two areas from the first area @param res_p pointer to an array of areas with a count of 4, the resulting areas will be stored here @param a1_p pointer to the first area @param a2_p pointer to the second area @return number of results (max 4) or -1 if no intersect