lv_array_at

Function lv_array_at 

pub unsafe extern "C" fn lv_array_at(
    array: *const lv_array_t,
    index: u32,
) -> *mut c_void
Returns a pointer to the element at position n in the array. @param array pointer to an lv_array_t variable @param index the index of the element to return @return a pointer to the requested element, NULL if index is out of range