pub unsafe extern "C" fn lv_array_concat(
array: *mut lv_array_t,
other: *const lv_array_t,
) -> lv_result_tExpand description
Concatenate two arrays. Adds new elements to the end of the array.
@note The destination array is automatically expanded as necessary.
@param array pointer to an lv_array_t variable
@param other pointer to the array to concatenate
@return LV_RESULT_OK: success, otherwise: error