lv_array_front

Function lv_array_front 

pub unsafe extern "C" fn lv_array_front(
    array: *const lv_array_t,
) -> *mut c_void
Returns a pointer to the first element in the array. @param array pointer to an lv_array_t variable @return a pointer to the first element in the array