lv_array_remove

Function lv_array_remove 

pub unsafe extern "C" fn lv_array_remove(
    array: *mut lv_array_t,
    index: u32,
) -> lv_result_t
Remove the element at the specified position in the array. @param array pointer to an lv_array_t variable @param index the index of the element to remove @return LV_RESULT_OK: success, otherwise: error