lv_buttonmatrix_create

Function lv_buttonmatrix_create 

pub unsafe extern "C" fn lv_buttonmatrix_create(
    parent: *mut lv_obj_t,
) -> *mut lv_obj_t
Create a button matrix object @param parent pointer to an object, it will be the parent of the new button matrix @return pointer to the created button matrix