lv_buttonmatrix_get_map

Function lv_buttonmatrix_get_map 

pub unsafe extern "C" fn lv_buttonmatrix_get_map(
    obj: *const lv_obj_t,
) -> *const *const c_char
Get the current map of a button matrix @param obj pointer to a button matrix object @return the current map