lv_buttonmatrix_has_button_ctrl

Function lv_buttonmatrix_has_button_ctrl 

pub unsafe extern "C" fn lv_buttonmatrix_has_button_ctrl(
    obj: *mut lv_obj_t,
    btn_id: u32,
    ctrl: lv_buttonmatrix_ctrl_t,
) -> bool
Get the whether a control value is enabled or disabled for button of a button matrix @param obj pointer to a button matrix object @param btn_id the index of a button not counting new line characters. @param ctrl control values to check (ORed value can be used) @return true: the control attribute is enabled false: disabled