lv_buttonmatrix_set_button_ctrl_all

Function lv_buttonmatrix_set_button_ctrl_all 

pub unsafe extern "C" fn lv_buttonmatrix_set_button_ctrl_all(
    obj: *mut lv_obj_t,
    ctrl: lv_buttonmatrix_ctrl_t,
)
Set attributes of all buttons of a button matrix @param obj pointer to a button matrix object @param ctrl attribute(s) to set from lv_buttonmatrix_ctrl_t. Values can be ORed.