lv_buttonmatrix_set_button_width

Function lv_buttonmatrix_set_button_width 

pub unsafe extern "C" fn lv_buttonmatrix_set_button_width(
    obj: *mut lv_obj_t,
    btn_id: u32,
    width: u32,
)
Set a single button’s relative width. This method will cause the matrix be regenerated and is a relatively expensive operation. It is recommended that initial width be specified using lv_buttonmatrix_set_ctrl_map and this method only be used for dynamic changes. @param obj pointer to button matrix object @param btn_id 0 based index of the button to modify. @param width relative width compared to the buttons in the same row. [1..15]