lv_buttonmatrix_set_ctrl_map

Function lv_buttonmatrix_set_ctrl_map 

pub unsafe extern "C" fn lv_buttonmatrix_set_ctrl_map(
    obj: *mut lv_obj_t,
    ctrl_map: *const lv_buttonmatrix_ctrl_t,
)
Set the button control map (hidden, disabled etc.) for a button matrix. The control map array will be copied and so may be deallocated after this function returns. @param obj pointer to a button matrix object @param ctrl_map pointer to an array of lv_button_ctrl_t control bytes. The length of the array and position of the elements must match the number and order of the individual buttons (i.e. excludes newline entries). An element of the map should look like e.g.: ctrl_map[0] = width | LV_BUTTONMATRIX_CTRL_NO_REPEAT | LV_BUTTONMATRIX_CTRL_TGL_ENABLE