lv_buttonmatrix_set_map

Function lv_buttonmatrix_set_map 

pub unsafe extern "C" fn lv_buttonmatrix_set_map(
    obj: *mut lv_obj_t,
    map: *const *const c_char,
)
Set a new map. Buttons will be created/deleted according to the map. The button matrix keeps a reference to the map and so the string array must not be deallocated during the life of the matrix. @param obj pointer to a button matrix object @param map pointer a string array. The last string has to be: “”. Use “\n” to make a line break.