lv_cache_acquire

Function lv_cache_acquire 

pub unsafe extern "C" fn lv_cache_acquire(
    cache: *mut lv_cache_t,
    key: *const c_void,
    user_data: *mut c_void,
) -> *mut lv_cache_entry_t
Acquire a cache entry with the given key. If entry not in cache, it will return NULL (not found). If the entry is found, it’s priority will be changed by the cache’s policy. And the lv_cache_entry_t::ref_cnt will be incremented. @param cache The cache object pointer to acquire the entry. @param key The key of the entry to acquire. @param user_data A user data pointer that will be passed to the create callback. @return Returns a pointer to the acquired cache entry on success with lv_cache_entry_t::ref_cnt incremented, NULL on error.