pub unsafe extern "C" fn lv_cache_entry_delete(
entry: *mut lv_cache_entry_t,
)Expand description
Deallocate a cache entry. And the data of the cache entry will be freed. @param entry The cache entry to deallocate.
pub unsafe extern "C" fn lv_cache_entry_delete(
entry: *mut lv_cache_entry_t,
)Deallocate a cache entry. And the data of the cache entry will be freed. @param entry The cache entry to deallocate.