lv_cache_entry_get_entry

Function lv_cache_entry_get_entry 

pub unsafe extern "C" fn lv_cache_entry_get_entry(
    data: *mut c_void,
    node_size: u32,
) -> *mut lv_cache_entry_t
Get the cache entry of a data. The data should be allocated by the cache instance. @param data The data to get the cache entry of. @param node_size The size of the node in the cache. @return The pointer to the cache entry of the data.