pub unsafe extern "C" fn lv_cache_get_name(
cache: *mut lv_cache_t,
) -> *const c_charExpand description
Get the name of a cache object. @param cache The cache object pointer to get the name. @return Returns the name of the cache.
pub unsafe extern "C" fn lv_cache_get_name(
cache: *mut lv_cache_t,
) -> *const c_charGet the name of a cache object. @param cache The cache object pointer to get the name. @return Returns the name of the cache.