lv_cache_release

Function lv_cache_release 

pub unsafe extern "C" fn lv_cache_release(
    cache: *mut lv_cache_t,
    entry: *mut lv_cache_entry_t,
    user_data: *mut c_void,
)
Release a cache entry. The lv_cache_entry_t::ref_cnt will be decremented. If the lv_cache_entry_t::ref_cnt is zero, it will issue an error. If the entry passed to this function is the last reference to the data and the entry is marked as invalid, the cache’s policy will be used to evict the entry. @param cache The cache object pointer to release the entry. @param entry The cache entry pointer to release. @param user_data A user data pointer that will be passed to the free callback.