lv_chart_get_y_array

Function lv_chart_get_y_array 

pub unsafe extern "C" fn lv_chart_get_y_array(
    obj: *const lv_obj_t,
    ser: *mut lv_chart_series_t,
) -> *mut i32
Get the array of y values of a series @param obj pointer to a chart object @param ser pointer to a data series on ‘chart’ @return the array of values with ‘point_count’ elements