lv_chart_set_ext_y_array

Function lv_chart_set_ext_y_array 

pub unsafe extern "C" fn lv_chart_set_ext_y_array(
    obj: *mut lv_obj_t,
    ser: *mut lv_chart_series_t,
    array: *mut i32,
)
Set an external array for the y data points to use for the chart NOTE: It is the users responsibility to make sure the point_cnt matches the external array size. @param obj pointer to a chart object @param ser pointer to a data series on ‘chart’ @param array external array of points for chart