lv_circle_buf_create

Function lv_circle_buf_create 

pub unsafe extern "C" fn lv_circle_buf_create(
    capacity: u32,
    element_size: u32,
) -> *mut lv_circle_buf_t
Create a circle buffer @param capacity the maximum number of elements in the buffer @param element_size the size of an element in bytes @return pointer to the created buffer