pub unsafe extern "C" fn lv_circle_buf_create_from_array(
array: *const lv_array_t,
) -> *mut lv_circle_buf_tExpand description
Create a circle buffer from an existing array @param array pointer to an array @return pointer to the created buffer
pub unsafe extern "C" fn lv_circle_buf_create_from_array(
array: *const lv_array_t,
) -> *mut lv_circle_buf_tCreate a circle buffer from an existing array @param array pointer to an array @return pointer to the created buffer