lv_display_get_layer_bottom

Function lv_display_get_layer_bottom 

pub unsafe extern "C" fn lv_display_get_layer_bottom(
    disp: *mut lv_display_t,
) -> *mut lv_obj_t
Return the bottom layer. The bottom layer is the same on all screen and it is under the normal screen layer. It’s visible only if the screen is transparent. @param disp pointer to display (NULL to use the default screen) @return pointer to the bottom layer object