lv_display_set_offset

Function lv_display_set_offset 

pub unsafe extern "C" fn lv_display_set_offset(
    disp: *mut lv_display_t,
    x: i32,
    y: i32,
)
If physical resolution is not the same as the normal resolution the offset of the active display area can be set here. @param disp pointer to a display @param x X offset @param y Y offset