lv_draw_buf_flush_cache

Function lv_draw_buf_flush_cache 

pub unsafe extern "C" fn lv_draw_buf_flush_cache(
    draw_buf: *const lv_draw_buf_t,
    area: *const lv_area_t,
)
Flush the cache of the buffer @param draw_buf the draw buffer needs to be flushed @param area the area to flush in the buffer, use NULL to flush the whole draw buffer address range