lv_draw_buf_invalidate_cache

Function lv_draw_buf_invalidate_cache 

pub unsafe extern "C" fn lv_draw_buf_invalidate_cache(
    draw_buf: *const lv_draw_buf_t,
    area: *const lv_area_t,
)
Invalidate the cache of the buffer @param draw_buf the draw buffer needs to be invalidated @param area the area to invalidate in the buffer, use NULL to invalidate the whole draw buffer address range