pub unsafe extern "C" fn lv_draw_dispatch_layer(
disp: *mut lv_display_t,
layer: *mut lv_layer_t,
) -> boolExpand description
Used internally to try dispatching draw tasks of a specific layer @param disp pointer to a display on which the dispatching was requested @param layer pointer to a layer @return at least one draw task is being rendered (maybe it was taken earlier)