pub unsafe extern "C" fn lv_event_code_get_name(
code: lv_event_code_t,
) -> *const c_charExpand description
Get the name of an event code. @param code the event code @return the name of the event code as a string
pub unsafe extern "C" fn lv_event_code_get_name(
code: lv_event_code_t,
) -> *const c_charGet the name of an event code. @param code the event code @return the name of the event code as a string