pub unsafe extern "C" fn lv_event_stop_processing(e: *mut lv_event_t)Expand description
Stop processing this event. This is only valid when called in the middle of an event processing chain. @param e pointer to the event descriptor
pub unsafe extern "C" fn lv_event_stop_processing(e: *mut lv_event_t)Stop processing this event. This is only valid when called in the middle of an event processing chain. @param e pointer to the event descriptor