pub unsafe extern "C" fn lv_image_cache_dump()Expand description
Dump the content of the image cache in a human-readable format with cache order.
pub unsafe extern "C" fn lv_image_cache_dump()Dump the content of the image cache in a human-readable format with cache order.