pub unsafe extern "C" fn lv_image_decoder_post_process(
dsc: *mut lv_image_decoder_dsc_t,
decoded: *mut lv_draw_buf_t,
) -> *mut lv_draw_buf_tExpand description
Check the decoded image, make any modification if decoder args requires.
@note A new draw buf will be allocated if provided decoded is not modifiable or stride mismatch etc.
@param dsc pointer to a decoder descriptor
@param decoded pointer to a decoded image to post process to meet dsc->args requirement.
@return post processed draw buffer, when it differs with decoded, it’s newly allocated.