lv_imagebutton_get_src_left

Function lv_imagebutton_get_src_left 

pub unsafe extern "C" fn lv_imagebutton_get_src_left(
    imagebutton: *mut lv_obj_t,
    state: lv_imagebutton_state_t,
) -> *const c_void
Get the left image in a given state @param imagebutton pointer to an image button object @param state the state where to get the image (from lv_button_state_t) ` @return pointer to the left image source (a C array or path to a file)