lv_imagebutton_get_src_middle

Function lv_imagebutton_get_src_middle 

pub unsafe extern "C" fn lv_imagebutton_get_src_middle(
    obj: *mut lv_obj_t,
    state: lv_imagebutton_state_t,
) -> *const c_void
Get the middle image in a given state @param obj pointer to an image button object @param state the state where to get the image (from lv_button_state_t) ` @return pointer to the middle image source (a C array or path to a file)