lv_imagebutton_set_src

Function lv_imagebutton_set_src 

pub unsafe extern "C" fn lv_imagebutton_set_src(
    obj: *mut lv_obj_t,
    state: lv_imagebutton_state_t,
    src_left: *const c_void,
    src_mid: *const c_void,
    src_right: *const c_void,
)
Set images for a state of the image button @param obj pointer to an image button object @param state for which state set the new image @param src_left pointer to an image source for the left side of the button (a C array or path to a file) @param src_mid pointer to an image source for the middle of the button (ideally 1px wide) (a C array or path to a file) @param src_right pointer to an image source for the right side of the button (a C array or path to a file)