lv_imagebutton_set_src_left

Function lv_imagebutton_set_src_left 

pub unsafe extern "C" fn lv_imagebutton_set_src_left(
    obj: *mut lv_obj_t,
    state: lv_imagebutton_state_t,
    src_left: *const c_void,
)
Set the left image for a state of the image button @param obj pointer to an image button object @param state for which state set the new image @param src_left pointer to an image source for the left side of the button (a C array or path to a file)