lv_imagebutton_set_src_mid

Function lv_imagebutton_set_src_mid 

pub unsafe extern "C" fn lv_imagebutton_set_src_mid(
    obj: *mut lv_obj_t,
    state: lv_imagebutton_state_t,
    src_mid: *const c_void,
)
Set the middle image for a state of the image button @param obj pointer to an image button object @param state for which state set the new image @param src_mid pointer to an image source for the middle of the button (a C array or path to a file)