pub unsafe extern "C" fn lv_indev_stop_processing(
indev: *mut lv_indev_t,
)Expand description
Touch and key related events are sent to the input device first and to the widget after that. If this functions called in an indev event, the event won’t be sent to the widget. @param indev pointer to an input device