pub unsafe extern "C" fn lv_map(
x: i32,
min_in: i32,
max_in: i32,
min_out: i32,
max_out: i32,
) -> i32Expand description
Get the mapped of a number given an input and output range @param x integer which mapped value should be calculated @param min_in min input range @param max_in max input range @param min_out max output range @param max_out max output range @return the mapped number