lv_obj_get_content_width

Function lv_obj_get_content_width 

pub unsafe extern "C" fn lv_obj_get_content_width(
    obj: *const lv_obj_t,
) -> i32
Get the width reduced by the left and right padding and the border width. @param obj pointer to an object @note The position of the object is recalculated only on the next redraw. To force coordinate recalculation call lv_obj_update_layout(obj). @return the width which still fits into its parent without causing overflow (making the parent scrollable)