pub unsafe extern "C" fn lv_obj_get_self_width(
obj: *const lv_obj_t,
) -> i32Expand description
Get the width occupied by the “parts” of the widget. E.g. the width of all columns of a table. @param obj pointer to an objects @return the width of the virtually drawn content @note This size independent from the real size of the widget. It just tells how large the internal (“virtual”) content is.