lv_obj_is_width_max

Function lv_obj_is_width_max 

pub unsafe extern "C" fn lv_obj_is_width_max(
    obj: *mut lv_obj_t,
) -> bool
@brief Determine if the object’s resolved width was limited by its maximum width constraint.

This function reports whether, in the most recent layout / size calculation, the object’s final (used) width had to be raised to satisfy a maximum width requirement.

@param obj Pointer to a valid object. @return true The computed width == the effective maximum width (i.e. it was clamped). @return false The width is smaller than the maximum (not min‑clamped).