lv_obj_remove_state

Function lv_obj_remove_state 

pub unsafe extern "C" fn lv_obj_remove_state(
    obj: *mut lv_obj_t,
    state: lv_state_t,
)
Remove one or more states to the object. The other state bits will remain unchanged. If specified in the styles, transition animation will be started from the previous state to the current. @param obj pointer to an object @param state the states to add. E.g LV_STATE_PRESSED | LV_STATE_FOCUSED