lv_obj_remove_theme

Function lv_obj_remove_theme 

pub unsafe extern "C" fn lv_obj_remove_theme(
    obj: *mut lv_obj_t,
    selector: lv_style_selector_t,
)
Remove all styles added by a theme from a widget @param selector OR-ed values of states and a part to remove only styles with matching selectors. LV_STATE_ANY and LV_PART_ANY can be used @param obj pointer to a widget