lv_obj_set_flex_align

Function lv_obj_set_flex_align 

pub unsafe extern "C" fn lv_obj_set_flex_align(
    obj: *mut lv_obj_t,
    main_place: lv_flex_align_t,
    cross_place: lv_flex_align_t,
    track_cross_place: lv_flex_align_t,
)
Set how to place (where to align) the items and tracks @param obj pointer to an object. The parent must have flex layout else nothing will happen. @param main_place where to place the items on main axis (in their track). Any value of lv_flex_align_t. @param cross_place where to place the item in their track on the cross axis. LV_FLEX_ALIGN_START/END/CENTER @param track_cross_place where to place the tracks in the cross direction. Any value of lv_flex_align_t.