pub unsafe extern "C" fn lv_obj_transform_point(
obj: *const lv_obj_t,
p: *mut lv_point_t,
flags: lv_obj_point_transform_flag_t,
)Expand description
Transform a point using the angle and zoom style properties of an object
@param obj pointer to an object whose style properties should be used
@param p a point to transform, the result will be written back here too
@param flags OR-ed valued of :cpp:enum:lv_obj_point_transform_flag_t