lv_obj_transform_point_array

Function lv_obj_transform_point_array 

pub unsafe extern "C" fn lv_obj_transform_point_array(
    obj: *const lv_obj_t,
    points: *mut lv_point_t,
    count: usize,
    flags: lv_obj_point_transform_flag_t,
)
Transform an array of points using the angle and zoom style properties of an object @param obj pointer to an object whose style properties should be used @param points the array of points to transform, the result will be written back here too @param count number of points in the array @param flags OR-ed valued of :cpp:enum:lv_obj_point_transform_flag_t