lv_obj_update_snap

Function lv_obj_update_snap 

pub unsafe extern "C" fn lv_obj_update_snap(
    obj: *mut lv_obj_t,
    anim_en: lv_anim_enable_t,
)
Check the children of obj and scroll obj to fulfill the scroll_snap settings @param obj an object whose children needs to checked and snapped @param anim_en LV_ANIM_ON/OFF