lv_point_array_transform

Function lv_point_array_transform 

pub unsafe extern "C" fn lv_point_array_transform(
    points: *mut lv_point_t,
    count: usize,
    angle: i32,
    scale_x: i32,
    scale_y: i32,
    pivot: *const lv_point_t,
    zoom_first: bool,
)
Transform an array of points @param points pointer to an array of points @param count number of points in the array @param angle angle with 0.1 resolutions (123 means 12.3°) @param scale_x horizontal zoom, 256 means 100% @param scale_y vertical zoom, 256 means 100% @param pivot pointer to the pivot point of the transformation @param zoom_first true: zoom first and rotate after that; else: opposite order