lv_reallocf

Function lv_reallocf 

pub unsafe extern "C" fn lv_reallocf(
    data_p: *mut c_void,
    new_size: usize,
) -> *mut c_void
Reallocate a memory with a new size. The old content will be kept. In case of failure, the old pointer is free’d. @param data_p pointer to an allocated memory. Its content will be copied to the new memory block and freed @param new_size the desired new size in byte @return pointer to the new memory, NULL on failure