lv_scale_set_angle_range

Function lv_scale_set_angle_range 

pub unsafe extern "C" fn lv_scale_set_angle_range(
    obj: *mut lv_obj_t,
    angle_range: u32,
)
Set angle between the low end and the high end of the Scale. (Applies only to round Scales.) @param obj pointer to Scale Widget @param max_angle angle in degrees from Scale minimum where top end of Scale will be drawn