lv_subject_init_string

Function lv_subject_init_string 

pub unsafe extern "C" fn lv_subject_init_string(
    subject: *mut lv_subject_t,
    buf: *mut c_char,
    prev_buf: *mut c_char,
    size: usize,
    value: *const c_char,
)
Initialize a string-type Subject. @param subject pointer to Subject @param buf pointer to buffer to store string @param prev_buf pointer to buffer to store previous string; can be NULL if not used @param size size of buffer(s) @param value initial value of string, e.g. “hello” @note A string Subject stores its own copy of the string, not just the pointer.