pub unsafe extern "C" fn lv_timer_pause(timer: *mut lv_timer_t)Expand description
Pause a timer. It is typically safe to call from an interrupt handler or a different thread. @param timer pointer to an lv_timer
pub unsafe extern "C" fn lv_timer_pause(timer: *mut lv_timer_t)Pause a timer. It is typically safe to call from an interrupt handler or a different thread. @param timer pointer to an lv_timer