lv_timer_set_auto_delete

Function lv_timer_set_auto_delete 

pub unsafe extern "C" fn lv_timer_set_auto_delete(
    timer: *mut lv_timer_t,
    auto_delete: bool,
)
Set whether a lv_timer will be deleted automatically when it is called repeat_count times. @param timer pointer to a lv_timer. @param auto_delete true: auto delete; false: timer will be paused when it is called repeat_count times.