_lv_draw_task_t

Struct _lv_draw_task_t 

#[repr(C)]
pub struct _lv_draw_task_t {
Show 13 fields pub next: *mut lv_draw_task_t, pub type_: lv_draw_task_type_t, pub area: lv_area_t, pub _real_area: lv_area_t, pub clip_area_original: lv_area_t, pub clip_area: lv_area_t, pub target_layer: *mut lv_layer_t, pub draw_unit: *mut lv_draw_unit_t, pub state: c_int, pub draw_dsc: *mut c_void, pub opa: lv_opa_t, pub preferred_draw_unit_id: u8, pub preference_score: u8,
}
TYPEDEFS

Fields

next: *mut lv_draw_task_ttype_: lv_draw_task_type_tarea: lv_area_t

The area where to draw

_real_area: lv_area_t

The real draw area. E.g. for shadow, outline, or transformed images it’s different from area

clip_area_original: lv_area_t

The original area which is updated

clip_area: lv_area_t

The clip area of the layer is saved here when the draw task is created. As the clip area of the layer can be changed as new draw tasks are added its current value needs to be saved. Therefore during drawing the layer’s clip area shouldn’t be used as it might be already changed for other draw tasks.

target_layer: *mut lv_layer_tdraw_unit: *mut lv_draw_unit_tstate: c_intdraw_dsc: *mut c_void

int instead of lv_draw_task_state_t to be sure its atomic

opa: lv_opa_t

Opacity of the layer

preferred_draw_unit_id: u8

The ID of the draw_unit which should take this task

preference_score: u8

Set to which extent preferred_draw_unit_id is good at this task. 80: means 20% better (faster) than software rendering 100: the default value 110: means 10% worse (slower) than software rendering