#[repr(C)]pub struct lv_group_t {
pub obj_ll: lv_ll_t,
pub obj_focus: *mut *mut lv_obj_t,
pub focus_cb: lv_group_focus_cb_t,
pub edge_cb: lv_group_edge_cb_t,
pub user_data: *mut c_void,
pub _bitfield_align_1: [u8; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>,
pub __bindgen_padding_0: [u8; 7],
}Expand description
Groups can be used to logically hold objects so that they can be individually focused. They are NOT for laying out objects on a screen (try layouts for that).
Fields
obj_ll: lv_ll_t< Linked list to store the objects in the group
obj_focus: *mut *mut lv_obj_t< The object in focus
focus_cb: lv_group_focus_cb_t< A function to call when a new object is focused (optional)
edge_cb: lv_group_edge_cb_t< A function to call when an edge is reached, no more focus targets are available in this direction (to allow edge feedback like a sound or a scroll bounce)
user_data: *mut c_void_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>__bindgen_padding_0: [u8; 7]Implementations
Sourceimpl lv_group_t
impl lv_group_t
pub fn frozen(&self) -> u8
pub fn set_frozen(&mut self, val: u8)
pub unsafe fn frozen_raw(this: *const Self) -> u8
pub unsafe fn set_frozen_raw(this: *mut Self, val: u8)
pub fn editing(&self) -> u8
pub fn set_editing(&mut self, val: u8)
pub unsafe fn editing_raw(this: *const Self) -> u8
pub unsafe fn set_editing_raw(this: *mut Self, val: u8)
pub fn refocus_policy(&self) -> u8
pub fn set_refocus_policy(&mut self, val: u8)
pub unsafe fn refocus_policy_raw(this: *const Self) -> u8
pub unsafe fn set_refocus_policy_raw(this: *mut Self, val: u8)
pub fn wrap(&self) -> u8
pub fn set_wrap(&mut self, val: u8)
pub unsafe fn wrap_raw(this: *const Self) -> u8
pub unsafe fn set_wrap_raw(this: *mut Self, val: u8)
pub fn new_bitfield_1( frozen: u8, editing: u8, refocus_policy: u8, wrap: u8, ) -> __BindgenBitfieldUnit<[u8; 1]>