#[repr(C)]pub struct lv_layer_t {
pub draw_buf: *mut lv_draw_buf_t,
pub buf_area: lv_area_t,
pub color_format: lv_color_format_t,
pub _clip_area: lv_area_t,
pub phy_clip_area: lv_area_t,
pub draw_task_head: *mut lv_draw_task_t,
pub parent: *mut lv_layer_t,
pub next: *mut lv_layer_t,
pub all_tasks_added: bool,
pub user_data: *mut c_void,
}Fields
draw_buf: *mut lv_draw_buf_tTarget draw buffer of the layer
buf_area: lv_area_tThe absolute coordinates of the buffer
color_format: lv_color_format_tThe color format of the layer. LV_COLOR_FORMAT_…
_clip_area: lv_area_tNEVER USE IT DRAW UNITS. USED INTERNALLY DURING DRAW TASK CREATION.
The current clip area with absolute coordinates, always the same or smaller than buf_area
Can be set before new draw tasks are added to indicate the clip area of the draw tasks.
Therefore lv_draw_add_task() always saves it in the new draw task to know the clip area when the draw task was added.
During drawing the draw units also sees the saved clip_area and should use it during drawing.
During drawing the layer’s clip area shouldn’t be used as it might be already changed for other draw tasks.
phy_clip_area: lv_area_tThe physical clipping area relative to the display.
draw_task_head: *mut lv_draw_task_tLinked list of draw tasks
parent: *mut lv_layer_tnext: *mut lv_layer_tall_tasks_added: booluser_data: *mut c_voidTrait Implementations
Sourceimpl Clone for lv_layer_t
impl Clone for lv_layer_t
Sourcefn clone(&self) -> lv_layer_t
fn clone(&self) -> lv_layer_t
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more