lv_obj_spec_attr_t

Struct lv_obj_spec_attr_t 

#[repr(C)]
pub struct lv_obj_spec_attr_t { pub children: *mut *mut lv_obj_t, pub group_p: *mut lv_group_t, pub event_list: lv_event_list_t, pub scroll: lv_point_t, pub ext_click_pad: i32, pub ext_draw_size: i32, pub child_cnt: u16, pub _bitfield_align_1: [u8; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 2]>, pub __bindgen_padding_0: u32, }
Special, rarely used attributes. They are allocated automatically if any elements is set.

Fields

children: *mut *mut lv_obj_t

< Store the pointer of the children in an array.

group_p: *mut lv_group_tevent_list: lv_event_list_tscroll: lv_point_t

< The current X/Y scroll offset

ext_click_pad: i32

< Extra click padding in all direction

ext_draw_size: i32

< EXTend the size in every direction for drawing.

child_cnt: u16

< Number of children

_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 2]>__bindgen_padding_0: u32

Implementations

Source

impl lv_obj_spec_attr_t

pub fn scrollbar_mode(&self) -> u16

pub fn set_scrollbar_mode(&mut self, val: u16)

pub unsafe fn scrollbar_mode_raw(this: *const Self) -> u16

pub unsafe fn set_scrollbar_mode_raw(this: *mut Self, val: u16)

pub fn scroll_snap_x(&self) -> u16

pub fn set_scroll_snap_x(&mut self, val: u16)

pub unsafe fn scroll_snap_x_raw(this: *const Self) -> u16

pub unsafe fn set_scroll_snap_x_raw(this: *mut Self, val: u16)

pub fn scroll_snap_y(&self) -> u16

pub fn set_scroll_snap_y(&mut self, val: u16)

pub unsafe fn scroll_snap_y_raw(this: *const Self) -> u16

pub unsafe fn set_scroll_snap_y_raw(this: *mut Self, val: u16)

pub fn scroll_dir(&self) -> u16

pub fn set_scroll_dir(&mut self, val: u16)

pub unsafe fn scroll_dir_raw(this: *const Self) -> u16

pub unsafe fn set_scroll_dir_raw(this: *mut Self, val: u16)

pub fn layer_type(&self) -> u16

pub fn set_layer_type(&mut self, val: u16)

pub unsafe fn layer_type_raw(this: *const Self) -> u16

pub unsafe fn set_layer_type_raw(this: *mut Self, val: u16)

pub fn new_bitfield_1( scrollbar_mode: u16, scroll_snap_x: u16, scroll_snap_y: u16, scroll_dir: u16, layer_type: u16, ) -> __BindgenBitfieldUnit<[u8; 2]>