#[repr(C)]pub struct lv_textarea_t {Show 14 fields
pub obj: lv_obj_t,
pub label: *mut lv_obj_t,
pub placeholder_txt: *mut c_char,
pub pwd_tmp: *mut c_char,
pub pwd_bullet: *mut c_char,
pub accepted_chars: *const c_char,
pub max_length: u32,
pub pwd_show_time: u32,
pub cursor: lv_textarea_t__bindgen_ty_1,
pub sel_start: u32,
pub sel_end: u32,
pub _bitfield_align_1: [u8; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>,
pub __bindgen_padding_0: [u8; 7],
}Expand description
Data of text area
Fields
obj: lv_obj_tlabel: *mut lv_obj_t< Label of the text area
placeholder_txt: *mut c_char< Place holder label. only visible if text is an empty string
pwd_tmp: *mut c_char< Used to store the original text in password mode
pwd_bullet: *mut c_char< Replacement characters displayed in password mode
accepted_chars: *const c_char< Only these characters will be accepted. NULL: accept all
max_length: u32< The max. number of characters. 0: no limit
pwd_show_time: u32< Time to show characters in password mode before change them to ‘*’
cursor: lv_textarea_t__bindgen_ty_1sel_start: u32< Temporary values for text selection
sel_end: u32_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>__bindgen_padding_0: [u8; 7]Implementations
Sourceimpl lv_textarea_t
impl lv_textarea_t
pub fn text_sel_in_prog(&self) -> u8
pub fn set_text_sel_in_prog(&mut self, val: u8)
pub unsafe fn text_sel_in_prog_raw(this: *const Self) -> u8
pub unsafe fn set_text_sel_in_prog_raw(this: *mut Self, val: u8)
pub fn text_sel_en(&self) -> u8
pub fn set_text_sel_en(&mut self, val: u8)
pub unsafe fn text_sel_en_raw(this: *const Self) -> u8
pub unsafe fn set_text_sel_en_raw(this: *mut Self, val: u8)
pub fn pwd_mode(&self) -> u8
pub fn set_pwd_mode(&mut self, val: u8)
pub unsafe fn pwd_mode_raw(this: *const Self) -> u8
pub unsafe fn set_pwd_mode_raw(this: *mut Self, val: u8)
pub fn one_line(&self) -> u8
pub fn set_one_line(&mut self, val: u8)
pub unsafe fn one_line_raw(this: *const Self) -> u8
pub unsafe fn set_one_line_raw(this: *mut Self, val: u8)
pub fn new_bitfield_1( text_sel_in_prog: u8, text_sel_en: u8, pwd_mode: u8, one_line: u8, ) -> __BindgenBitfieldUnit<[u8; 1]>