lv_scale_section_t

Type Alias lv_scale_section_t 

pub type lv_scale_section_t = _lv_scale_section_t;
TYPEDEFS

Aliased Type

#[repr(C)]
pub struct lv_scale_section_t {
Show 14 fields pub main_style: *const lv_style_t, pub indicator_style: *const lv_style_t, pub items_style: *const lv_style_t, pub range_min: i32, pub range_max: i32, pub first_tick_idx_in_section: u32, pub last_tick_idx_in_section: u32, pub first_tick_in_section_width: i32, pub last_tick_in_section_width: i32, pub first_tick_in_section: lv_point_t, pub last_tick_in_section: lv_point_t, pub _bitfield_align_1: [u8; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>, pub __bindgen_padding_0: [u8; 7],
}

Fields

main_style: *const lv_style_t

Style to use for MAIN part(s) of scale when it falls within this section’s range

indicator_style: *const lv_style_t

Style to use for INDICATOR part(s) of scale when it falls within this section’s range

items_style: *const lv_style_t

Style to use for ITEMS part(s) of scale when it falls within this section’s range

range_min: i32

< Scale parts with value >= this value will be drawn using applicable style.

range_max: i32

< Scale parts with value <= this value will be drawn using applicable style.

first_tick_idx_in_section: u32

< Internal (set during drawing): Tick index of first tick that falls within this section; LV_SCALE_TICK_IDX_DEFAULT_ID if section contains no ticks.

last_tick_idx_in_section: u32

< Internal (set during drawing): Tick index of last tick that falls within this section; LV_SCALE_TICK_IDX_DEFAULT_ID if section contains no ticks.

first_tick_in_section_width: i32

< Internal (set during drawing)

last_tick_in_section_width: i32

< Internal (set during drawing)

first_tick_in_section: lv_point_t

< Internal (set during drawing)

last_tick_in_section: lv_point_t

< Internal (set during drawing)

_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>__bindgen_padding_0: [u8; 7]