lv_array_assign

Function lv_array_assign 

pub unsafe extern "C" fn lv_array_assign(
    array: *mut lv_array_t,
    index: u32,
    value: *const c_void,
) -> lv_result_t
Assigns one content to the array, replacing its current content. @param array pointer to an lv_array_t variable @param index the index of the element to replace @param value pointer to the elements to add @return true: success; false: error