lv_array_copy

Function lv_array_copy 

pub unsafe extern "C" fn lv_array_copy(
    target: *mut lv_array_t,
    source: *const lv_array_t,
)
Copy an array to another. @note this will create a new array with the same capacity and size as the source array. @param target pointer to an lv_array_t variable to copy to @param source pointer to an lv_array_t variable to copy from