pub unsafe extern "C" fn lv_array_erase(
array: *mut lv_array_t,
start: u32,
end: u32,
) -> lv_result_tExpand description
Remove from the array either a single element or a range of elements ([start, end)).
@note This effectively reduces the container size by the number of elements removed.
@note When start equals to end, the function has no effect.
@param array pointer to an lv_array_t variable
@param start the index of the first element to be removed
@param end the index of the first element that is not to be removed
@return LV_RESULT_OK: success, otherwise: error