pub unsafe extern "C" fn lv_array_push_back(
array: *mut lv_array_t,
element: *const c_void,
) -> lv_result_tExpand description
Push back element. Adds a new element to the end of the array.
If the array capacity is not enough for the new element, the array will be resized automatically.
@note If the element is NULL, it will be added as an empty element.
@param array pointer to an lv_array_t variable
@param element pointer to the element to add. NULL to push an empty element.
@return LV_RESULT_OK: success, otherwise: error