pub unsafe extern "C" fn lv_array_remove_unordered(
array: *mut lv_array_t,
index: u32,
) -> lv_result_tExpand description
Remove the element at the specified position in the array.
This function does not guarantee the array order. Complexity is O(1)
@param array pointer to an lv_array_t variable
@param index the index of the element to remove
@return LV_RESULT_OK: success, otherwise: error