pub unsafe extern "C" fn lv_cache_drop_all(
cache: *mut lv_cache_t,
user_data: *mut c_void,
)Expand description
Drop all cache entries. All entries will be removed from the cache and their data will be freed when the last reference to them is released. @note If some entries are still referenced by other objects, it will issue an error. And this case shouldn’t happen in normal cases.. @param cache The cache object pointer to drop all entries. @param user_data A user data pointer that will be passed to the free callback.