pub unsafe extern "C" fn lv_cache_entry_alloc(
node_size: u32,
cache: *const lv_cache_t,
) -> *mut lv_cache_entry_tExpand description
Allocate a cache entry. @param node_size The size of the node in the cache. @param cache The cache instance to allocate the cache entry from. @return The pointer to the allocated cache entry.