lv_cache_entry_get_cache

Function lv_cache_entry_get_cache 

pub unsafe extern "C" fn lv_cache_entry_get_cache(
    entry: *const lv_cache_entry_t,
) -> *const lv_cache_t
Get the cache instance of a cache entry. @param entry The cache entry to get the cache instance of. @return The pointer to the cache instance of the cache entry.