pub unsafe extern "C" fn lv_cache_entry_get_data(
entry: *mut lv_cache_entry_t,
) -> *mut c_voidExpand description
Get the data of a cache entry. @param entry The cache entry to get the data of. @return The pointer to the data of the cache entry.