pub unsafe extern "C" fn lv_cache_entry_init(
entry: *mut lv_cache_entry_t,
cache: *const lv_cache_t,
node_size: u32,
)Expand description
Initialize a cache entry. @param entry The cache entry to initialize. @param cache The cache instance to allocate the cache entry from. @param node_size The size of the node in the cache.