pub unsafe extern "C" fn lv_cache_is_enabled(
cache: *mut lv_cache_t,
) -> boolExpand description
Return true if the cache is enabled. Disabled cache means that when the max_size of the cache is 0. In this case, all cache operations will be no-op. @param cache The cache object pointer to check if it’s disabled. @return Returns true if the cache is enabled, false otherwise.