pub unsafe extern "C" fn lv_cache_iter_create(
cache: *mut lv_cache_t,
) -> *mut lv_iter_tExpand description
Create an iterator for the cache object. The iterator is used to iterate over all cache entries.
@param cache The cache object pointer to create the iterator.
@return Returns a pointer to the created iterator on success, NULL on error.