pub unsafe extern "C" fn lv_image_header_cache_resize(
count: u32,
evict_now: bool,
)Expand description
Resize image header cache. If set to 0, the cache is disabled. @param count new max count of cached image headers. @param evict_now true: evict the image headers should be removed by the eviction policy, false: wait for the next cache cleanup.