pub unsafe extern "C" fn lv_imagebutton_create(
parent: *mut lv_obj_t,
) -> *mut lv_obj_tExpand description
Create an image button object @param parent pointer to an object, it will be the parent of the new image button @return pointer to the created image button