pub unsafe extern "C" fn lv_imagebutton_set_src_right(
obj: *mut lv_obj_t,
state: lv_imagebutton_state_t,
src_right: *const c_void,
)Expand description
Set the right image for a state of the image button @param obj pointer to an image button object @param state for which state set the new image @param src_right pointer to an image source for the right side of the button (a C array or path to a file)