pub unsafe extern "C" fn lv_menu_section_create(
parent: *mut lv_obj_t,
) -> *mut lv_obj_tExpand description
Create a menu section object @param parent pointer to a menu page object, it will be the parent of the new menu section object @return pointer to the created menu section