pub unsafe extern "C" fn lv_obj_get_scroll_bottom(
obj: *const lv_obj_t,
) -> i32Expand description
Number of pixels a scrollable container Widget can be scrolled up before its bottom edge appears. When LV_OBJ_FLAG_SCROLL_ELASTIC flag is set in Widget, this value can go negative while Widget is being dragged above its normal bottom-edge boundary. @param obj pointer to scrollable container Widget @return pixels Widget can be scrolled up before its bottom edge appears