pub unsafe extern "C" fn lv_obj_get_scroll_bottom(
obj: *mut lv_obj_t,
) -> i32Expand description
Return the height of the area below the object. That is the number of pixels the object can be scrolled down. Normally positive but can be negative when scrolled inside. @param obj pointer to an object @return the scrollable area below the object in pixels