pub unsafe extern "C" fn lv_obj_get_scroll_left(
obj: *const lv_obj_t,
) -> i32Expand description
Number of pixels a scrollable container Widget can be scrolled right before its left edge appears. When LV_OBJ_FLAG_SCROLL_ELASTIC flag is set in Widget, this value can go negative while Widget is being dragged farther right than its normal left-edge boundary. @param obj pointer to scrollable container Widget @return pixels Widget can be scrolled right before its left edge appears