pub unsafe extern "C" fn lv_strcmp(
s1: *const c_char,
s2: *const c_char,
) -> c_intExpand description
@brief This function will compare two strings without specified length. @param s1 pointer to the first string @param s2 pointer to the second string @return the difference between the value of the first unmatching character.