pub unsafe extern "C" fn lv_table_set_cell_user_data(
obj: *mut lv_obj_t,
row: u16,
col: u16,
user_data: *mut c_void,
)Expand description
Add custom user data to the cell.
@param obj pointer to a Table object
@param row id of the row [0 .. row_cnt -1]
@param col id of the column [0 .. col_cnt -1]
@param user_data pointer to the new user_data.
Should be allocated by lv_malloc,
and it will be freed automatically when the table is deleted or
when the cell is dropped due to lower row or column count.