pub unsafe extern "C" fn lv_text_get_width(
txt: *const c_char,
length: u32,
font: *const lv_font_t,
attributes: *const lv_text_attributes_t,
) -> i32Expand description
Give the length of a text with a given font with text flags @param txt a ‘\0’ terminate string @param length length of ‘txt’ in byte count and not characters (Á is 1 character but 2 bytes in UTF-8) @param font pointer to font of the text @param attributes the text attributes, flags for line break behaviour, spacing etc @return length of a char_num long text