pub unsafe extern "C" fn lv_textarea_set_insert_replace(
obj: *mut lv_obj_t,
txt: *const c_char,
)Expand description
In LV_EVENT_INSERT the text which planned to be inserted can be replaced by another text.
It can be used to add automatic formatting to the text area.
@param obj pointer to a text area object
@param txt pointer to a new string to insert. If "" no text will be added.
The variable must be live after the event_cb exists. (Should be global or static)