pub unsafe extern "C" fn lv_thread_init(
thread: *mut lv_thread_t,
prio: lv_thread_prio_t,
callback: Option<unsafe extern "C" fn(arg1: *mut c_void)>,
stack_size: usize,
user_data: *mut c_void,
) -> lv_result_tExpand description
Create a new thread @param thread a variable in which the thread will be stored @param prio priority of the thread @param callback function of the thread @param stack_size stack size in bytes @param user_data arbitrary data, will be available in the callback @return LV_RESULT_OK: success; LV_RESULT_INVALID: failure