#[repr(C)]pub struct lv_display_t {Show 49 fields
pub hor_res: i32,
pub ver_res: i32,
pub physical_hor_res: i32,
pub physical_ver_res: i32,
pub offset_x: i32,
pub offset_y: i32,
pub dpi: u32,
pub buf_1: *mut lv_draw_buf_t,
pub buf_2: *mut lv_draw_buf_t,
pub buf_act: *mut lv_draw_buf_t,
pub flush_cb: lv_display_flush_cb_t,
pub flush_wait_cb: lv_display_flush_wait_cb_t,
pub flushing: c_int,
pub flushing_last: c_int,
pub _bitfield_align_1: [u8; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>,
pub render_mode: lv_display_render_mode_t,
pub _bitfield_align_2: [u8; 0],
pub _bitfield_2: __BindgenBitfieldUnit<[u8; 1]>,
pub color_format: lv_color_format_t,
pub inv_areas: [lv_area_t; 32],
pub inv_area_joined: [u8; 32],
pub inv_p: u32,
pub inv_en_cnt: i32,
pub sync_areas: lv_ll_t,
pub _static_buf1: lv_draw_buf_t,
pub _static_buf2: lv_draw_buf_t,
pub layer_head: *mut lv_layer_t,
pub layer_init: Option<unsafe extern "C" fn(disp: *mut lv_display_t, layer: *mut lv_layer_t)>,
pub layer_deinit: Option<unsafe extern "C" fn(disp: *mut lv_display_t, layer: *mut lv_layer_t)>,
pub screens: *mut *mut lv_obj_t,
pub sys_layer: *mut lv_obj_t,
pub top_layer: *mut lv_obj_t,
pub act_scr: *mut lv_obj_t,
pub bottom_layer: *mut lv_obj_t,
pub prev_scr: *mut lv_obj_t,
pub scr_to_load: *mut lv_obj_t,
pub screen_cnt: u32,
pub _bitfield_align_3: [u8; 0],
pub _bitfield_3: __BindgenBitfieldUnit<[u8; 1]>,
pub driver_data: *mut c_void,
pub user_data: *mut c_void,
pub event_list: lv_event_list_t,
pub _bitfield_align_4: [u8; 0],
pub _bitfield_4: __BindgenBitfieldUnit<[u8; 1]>,
pub theme: *mut lv_theme_t,
pub refr_timer: *mut lv_timer_t,
pub last_activity_time: u32,
pub refreshed_area: lv_area_t,
}Expand description
TYPEDEFS
Fields
hor_res: i32Horizontal resolution.
ver_res: i32Vertical resolution.
physical_hor_res: i32Horizontal resolution of the full / physical display. Set to -1 for fullscreen mode.
physical_ver_res: i32Vertical resolution of the full / physical display. Set to -1 for fullscreen mode.
offset_x: i32Horizontal offset from the full / physical display. Set to 0 for fullscreen mode.
offset_y: i32Vertical offset from the full / physical display. Set to 0 for fullscreen mode.
dpi: u32DPI (dot per inch) of the display. Default value is LV_DPI_DEF.
buf_1: *mut lv_draw_buf_tbuf_2: *mut lv_draw_buf_tbuf_act: *mut lv_draw_buf_tInternal, used by the library
flush_cb: lv_display_flush_cb_tMANDATORY: Write the internal buffer (draw_buf) to the display. ‘lv_display_flush_ready()’ has to be called when finished
flush_wait_cb: lv_display_flush_wait_cb_tUsed to wait while flushing is ready.
It can do any complex logic to wait, including semaphores, mutexes, polling flags, etc.
If not set flushing flag is used which can be cleared with lv_display_flush_ready()
flushing: c_int1: flushing is in progress. (It can’t be a bit field because when it’s cleared from IRQ Read-Modify-Write issue might occur)
flushing_last: c_int1: It was the last chunk to flush. (It can’t be a bit field because when it’s cleared from IRQ Read-Modify-Write issue might occur)
_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>render_mode: lv_display_render_mode_t_bitfield_align_2: [u8; 0]_bitfield_2: __BindgenBitfieldUnit<[u8; 1]>color_format: lv_color_format_tinv_areas: [lv_area_t; 32]Invalidated (marked to redraw) areas
inv_area_joined: [u8; 32]inv_p: u32inv_en_cnt: i32sync_areas: lv_ll_tDouble buffer sync areas (redrawn during last refresh)
_static_buf1: lv_draw_buf_t< Used when user pass in a raw buffer as display draw buffer
_static_buf2: lv_draw_buf_tlayer_head: *mut lv_layer_tlayer_init: Option<unsafe extern "C" fn(disp: *mut lv_display_t, layer: *mut lv_layer_t)>layer_deinit: Option<unsafe extern "C" fn(disp: *mut lv_display_t, layer: *mut lv_layer_t)>screens: *mut *mut lv_obj_t< Array of screen objects.
sys_layer: *mut lv_obj_t< @see lv_display_get_layer_sys
top_layer: *mut lv_obj_t< @see lv_display_get_layer_top
act_scr: *mut lv_obj_t< Currently active screen on this display
bottom_layer: *mut lv_obj_t< @see lv_display_get_layer_bottom
prev_scr: *mut lv_obj_t< Previous screen. Used during screen animations
scr_to_load: *mut lv_obj_t< The screen prepared to load in lv_screen_load_anim
screen_cnt: u32_bitfield_align_3: [u8; 0]_bitfield_3: __BindgenBitfieldUnit<[u8; 1]>driver_data: *mut c_void< Custom user data
user_data: *mut c_void< Custom user data
event_list: lv_event_list_t_bitfield_align_4: [u8; 0]_bitfield_4: __BindgenBitfieldUnit<[u8; 1]>theme: *mut lv_theme_t< The theme assigned to the screen
refr_timer: *mut lv_timer_tA timer which periodically checks the dirty areas and refreshes them
last_activity_time: u32< Last time when there was activity on this display
refreshed_area: lv_area_tThe area being refreshed
Implementations
Sourceimpl lv_display_t
impl lv_display_t
pub fn last_area(&self) -> u32
pub fn set_last_area(&mut self, val: u32)
pub unsafe fn last_area_raw(this: *const Self) -> u32
pub unsafe fn set_last_area_raw(this: *mut Self, val: u32)
pub fn last_part(&self) -> u32
pub fn set_last_part(&mut self, val: u32)
pub unsafe fn last_part_raw(this: *const Self) -> u32
pub unsafe fn set_last_part_raw(this: *mut Self, val: u32)
pub fn new_bitfield_1( last_area: u32, last_part: u32, ) -> __BindgenBitfieldUnit<[u8; 1]>
pub fn antialiasing(&self) -> u32
pub fn set_antialiasing(&mut self, val: u32)
pub unsafe fn antialiasing_raw(this: *const Self) -> u32
pub unsafe fn set_antialiasing_raw(this: *mut Self, val: u32)
pub fn rendering_in_progress(&self) -> u32
pub fn set_rendering_in_progress(&mut self, val: u32)
pub unsafe fn rendering_in_progress_raw(this: *const Self) -> u32
pub unsafe fn set_rendering_in_progress_raw(this: *mut Self, val: u32)
pub fn new_bitfield_2( antialiasing: u32, rendering_in_progress: u32, ) -> __BindgenBitfieldUnit<[u8; 1]>
pub fn draw_prev_over_act(&self) -> u8
pub fn set_draw_prev_over_act(&mut self, val: u8)
pub unsafe fn draw_prev_over_act_raw(this: *const Self) -> u8
pub unsafe fn set_draw_prev_over_act_raw(this: *mut Self, val: u8)
pub fn del_prev(&self) -> u8
pub fn set_del_prev(&mut self, val: u8)
pub unsafe fn del_prev_raw(this: *const Self) -> u8
pub unsafe fn set_del_prev_raw(this: *mut Self, val: u8)
pub fn new_bitfield_3( draw_prev_over_act: u8, del_prev: u8, ) -> __BindgenBitfieldUnit<[u8; 1]>
pub fn rotation(&self) -> u32
pub fn set_rotation(&mut self, val: u32)
pub unsafe fn rotation_raw(this: *const Self) -> u32
pub unsafe fn set_rotation_raw(this: *mut Self, val: u32)
pub fn new_bitfield_4(rotation: u32) -> __BindgenBitfieldUnit<[u8; 1]>