#[repr(C)]pub struct lv_image_decoder_dsc_t {Show 14 fields
pub decoder: *mut lv_image_decoder_t,
pub args: lv_image_decoder_args_t,
pub src: *const c_void,
pub src_type: lv_image_src_t,
pub file: lv_fs_file_t,
pub header: lv_image_header_t,
pub decoded: *const lv_draw_buf_t,
pub palette: *const lv_color32_t,
pub palette_size: u32,
pub time_to_open: u32,
pub error_msg: *const c_char,
pub cache: *mut lv_cache_t,
pub cache_entry: *mut lv_cache_entry_t,
pub user_data: *mut c_void,
}Expand description
Describe an image decoding session. Stores data about the decoding
Fields
decoder: *mut lv_image_decoder_tThe decoder which was able to open the image source
args: lv_image_decoder_args_tA copy of parameters of how this image is decoded
src: *const c_voidThe image source. A file path like “S:my_img.png” or pointer to an lv_image_dsc_t variable
src_type: lv_image_src_tType of the source: file or variable. Can be set in open function if required
file: lv_fs_file_theader: lv_image_header_tInfo about the opened image: color format, size, etc. MUST be set in open function
decoded: *const lv_draw_buf_tPointer to a draw buffer where the image’s data (pixels) are stored in a decoded, plain format.
MUST be set in open or get_area_cbfunction
palette: *const lv_color32_tpalette_size: u32time_to_open: u32How much time did it take to open the image. [ms]
If not set lv_image_cache will measure and set the time to open
error_msg: *const c_charA text to display instead of the image when the image can’t be opened.
Can be set in open function or set NULL.
cache: *mut lv_cache_tcache_entry: *mut lv_cache_entry_tPoint to cache entry information
user_data: *mut c_voidStore any custom data here is required