pub type lv_draw_task_t = _lv_draw_task_t;Expand description
TYPEDEFS
Aliased Type
#[repr(C)]pub struct lv_draw_task_t {Show 13 fields
pub next: *mut _lv_draw_task_t,
pub type_: u32,
pub area: lv_area_t,
pub _real_area: lv_area_t,
pub clip_area_original: lv_area_t,
pub clip_area: lv_area_t,
pub target_layer: *mut _lv_layer_t,
pub draw_unit: *mut _lv_draw_unit_t,
pub state: i32,
pub draw_dsc: *mut c_void,
pub opa: u8,
pub preferred_draw_unit_id: u8,
pub preference_score: u8,
}Fields
next: *mut _lv_draw_task_ttype_: u32area: lv_area_tThe area where to draw
_real_area: lv_area_tThe real draw area. E.g. for shadow, outline, or transformed images it’s different from area
clip_area_original: lv_area_tThe original area which is updated
clip_area: lv_area_tThe clip area of the layer is saved here when the draw task is created. As the clip area of the layer can be changed as new draw tasks are added its current value needs to be saved. Therefore during drawing the layer’s clip area shouldn’t be used as it might be already changed for other draw tasks.
target_layer: *mut _lv_layer_tdraw_unit: *mut _lv_draw_unit_tstate: i32draw_dsc: *mut c_voidint instead of lv_draw_task_state_t to be sure its atomic
opa: u8Opacity of the layer
preferred_draw_unit_id: u8The ID of the draw_unit which should take this task
preference_score: u8Set to which extent preferred_draw_unit_id is good at this task.
80: means 20% better (faster) than software rendering
100: the default value
110: means 10% worse (slower) than software rendering