pub type lv_layer_t = _lv_layer_t;Aliased Type
#[repr(C)]pub struct lv_layer_t {Show 13 fields
pub draw_buf: *mut _lv_draw_buf_t,
pub draw_task_head: *mut _lv_draw_task_t,
pub parent: *mut _lv_layer_t,
pub next: *mut _lv_layer_t,
pub user_data: *mut c_void,
pub buf_area: lv_area_t,
pub phy_clip_area: lv_area_t,
pub _clip_area: lv_area_t,
pub partial_y_offset: i32,
pub recolor: lv_color32_t,
pub color_format: u32,
pub all_tasks_added: bool,
pub opa: u8,
}Fields
draw_buf: *mut _lv_draw_buf_tTarget draw buffer of the layer
draw_task_head: *mut _lv_draw_task_tLinked list of draw tasks
parent: *mut _lv_layer_tParent layer
next: *mut _lv_layer_tNext layer
user_data: *mut c_voidUser data
buf_area: lv_area_tThe absolute coordinates of the buffer
phy_clip_area: lv_area_tThe physical clipping area relative to the display
_clip_area: lv_area_tNEVER USE IT DRAW UNITS. USED INTERNALLY DURING DRAW TASK CREATION.
The current clip area with absolute coordinates, always the same or smaller than buf_area
Can be set before new draw tasks are added to indicate the clip area of the draw tasks.
Therefore lv_draw_add_task() always saves it in the new draw task to know the clip area when the draw task was added.
During drawing the draw units also sees the saved clip_area and should use it during drawing.
During drawing the layer’s clip area shouldn’t be used as it might be already changed for other draw tasks.
partial_y_offset: i32Partial y offset
recolor: lv_color32_tRecolor of the layer
color_format: u32The color format of the layer. LV_COLOR_FORMAT_…
all_tasks_added: boolFlag indicating all tasks are added
opa: u8Opacity of the layer