lv_layer_t

Type Alias lv_layer_t 

pub type lv_layer_t = _lv_layer_t;

Aliased Type

#[repr(C)]
pub struct lv_layer_t {
Show 13 fields pub draw_buf: *mut _lv_draw_buf_t, pub buf_area: lv_area_t, pub color_format: u32, pub _clip_area: lv_area_t, pub phy_clip_area: lv_area_t, pub opa: u8, pub recolor: lv_color32_t, pub partial_y_offset: i32, pub draw_task_head: *mut _lv_draw_task_t, pub parent: *mut _lv_layer_t, pub next: *mut _lv_layer_t, pub all_tasks_added: bool, pub user_data: *mut c_void,
}

Fields

draw_buf: *mut _lv_draw_buf_t

Target draw buffer of the layer

buf_area: lv_area_t

The absolute coordinates of the buffer

color_format: u32

The color format of the layer. LV_COLOR_FORMAT_…

_clip_area: lv_area_t

NEVER USE IT DRAW UNITS. USED INTERNALLY DURING DRAW TASK CREATION. The current clip area with absolute coordinates, always the same or smaller than buf_area Can be set before new draw tasks are added to indicate the clip area of the draw tasks. Therefore lv_draw_add_task() always saves it in the new draw task to know the clip area when the draw task was added. During drawing the draw units also sees the saved clip_area and should use it during drawing. During drawing the layer’s clip area shouldn’t be used as it might be already changed for other draw tasks.

phy_clip_area: lv_area_t

The physical clipping area relative to the display.

opa: u8

Opacity of the layer

recolor: lv_color32_tpartial_y_offset: i32

Partial y offset

draw_task_head: *mut _lv_draw_task_t

Linked list of draw tasks

parent: *mut _lv_layer_tnext: *mut _lv_layer_tall_tasks_added: booluser_data: *mut c_void