pub type lv_scale_t = _lv_scale_t;Aliased Type
#[repr(C)]pub struct lv_scale_t {Show 14 fields
pub obj: _lv_obj_t,
pub section_ll: lv_ll_t,
pub txt_src: *mut *const i8,
pub mode: u32,
pub range_min: i32,
pub range_max: i32,
pub _bitfield_align_1: [u16; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 5]>,
pub angle_range: u32,
pub rotation: i32,
pub custom_label_cnt: i32,
pub last_tick_width: i32,
pub first_tick_width: i32,
pub needles: _lv_array_t,
}Fields
obj: _lv_obj_t< Base Widget part of Scale
section_ll: lv_ll_t< Linked list for the sections (stores lv_scale_section_t)
txt_src: *mut *const i8< Optional list of text strings for major ticks when custom labels are provided.
mode: u32< Orientation and layout of scale.
range_min: i32< Scale’s minimum value
range_max: i32< Scale’s maximum value
_bitfield_align_1: [u16; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 5]>angle_range: u32< Degrees between low end and high end of scale
rotation: i32< Clockwise angular offset from 3-o’clock position of low end of scale
custom_label_cnt: i32< Number of custom labels provided in txt_src
last_tick_width: i32< Width of last tick in pixels
first_tick_width: i32< Width of first tick in pixels
needles: _lv_array_t< Needle list of this scale